<?php namespace Wordpress\Play;


class Play_Requests extends Component {


	/**
	 * Constructor
	 *
	 * @return void
	 */
	protected function init() {
		parent::init();

		// conversion scripts
		add_action( 'admin_enqueue_scripts', [ &$this, 'load_admin_play_requests' ] );

	}

	/**
	 * Load scripts for requests
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function load_admin_play_requests() {
		// load path for scripts
		$load_path = WPPP_URI . ( Helpers::is_script_debugging() ? 'assets/src/' : 'assets/dist/' );
		$images_path = WPPP_URI . 'assets/images/';

		// handle back url upon register and subscription, load script to save appId and uid
		if ( isset( $_GET[ 'appId' ] ) && isset( $_GET[ 'uid' ] ) && isset( $_GET[ 'page' ] ) && 'play-welcome-page' == $_GET[ 'page' ] ) {

			$appId  = filter_input( INPUT_GET, 'appId', FILTER_SANITIZE_STRING );
			$userId = filter_input( INPUT_GET, 'uid', FILTER_SANITIZE_STRING );
			$blog   = site_url();

			if ( preg_match( "/https?:/", site_url() ) ) {
				$blog = preg_replace( '/https?:\/\//', '', site_url() );
			}

			// save play query params
			update_option( 'wppp_blog_appId', $appId );
			update_option( 'wppp_blog_userId', $userId );

			// flag 1 (user connected to play)
			update_option( 'wppp_status_flag', 1 );

			// add blog domain to remote
			wp_enqueue_script( 'add_blog_domain', $load_path . 'js/add_blog_domain.js', [
				'jquery',
			], wppp_version(), true );

			// localizing script.
			wp_localize_script( 'add_blog_domain', 'wppp_blog', [
				'ajax_url' => Add_Origin_URL,
				'user_id'  => $userId,
				'app_id'   => $appId,
				'bolg'     => $blog,
			] );

			wp_enqueue_script( 'helpers', $load_path . 'js/helpers.js', [ ], wppp_version(), true );

			// register firebase script.
			wp_register_script( 'firebase_script', 'https://www.gstatic.com/firebasejs/4.2.0/firebase.js', [ ], wppp_version(), true );
			
			// initialize firebase
			wp_enqueue_script( 'initialize_firebase', $load_path . 'js/initialize_firebase.js', [
				'jquery',
				'firebase_script',
			], wppp_version(), true );

			wp_enqueue_script( 'retrieve_user_data', $load_path . 'js/retrieve_user_data.js', [
				'jquery',
				'firebase_script',
				'helpers',
			], wppp_version(), true );

			// localizing script.
			wp_localize_script( 'retrieve_user_data', 'wppp_retrieve', [
				'user_id'  => get_option( 'wppp_blog_userId' ),
				'app_id'  => get_option( 'wppp_blog_appId' ),
				'ajax_url' => admin_url( 'admin-ajax.php' ),
			] );

			// send referral theme
			wp_enqueue_script( 'referral_theme', $load_path . 'js/referral_theme.js', [
				'jquery',
			], wppp_version(), true );

			// localizing script.
			wp_localize_script( 'referral_theme', 'wppp_theme', [
				'ajax_url' => REFERRAL_URL,
				'user_id'  => $userId,
				'theme'    => get_template(),
			] );

		}

		// load conversion script only in edit
		if ( isset( $_GET[ 'action' ] ) && isset( $_GET[ 'action' ] ) && $_GET[ 'action' ] === 'edit' ) {

			$post_id = filter_input( INPUT_GET, 'post', FILTER_SANITIZE_NUMBER_INT );
			// google analytics script
			wp_enqueue_script( 'analytics', $load_path . 'js/analytics.js', [
				'jquery',
			], wppp_version(), true );

			// regeneratorRuntime polyfill
			wp_enqueue_script( 'regenerator_runtime', $load_path .'js/regenerator_runtime.js', [ ], wppp_version(), true );

			wp_enqueue_script( 'crisp_chat', $load_path . 'js/crisp_chat.js', [ ], wppp_version(), true );
			wp_enqueue_script( 'sweetalert', $load_path . 'js/sweetalert.min.js', [ ], wppp_version(), true );
			// register sentry
			wp_register_script( 'sentry_script', 'https://browser.sentry-cdn.com/5.7.1/bundle.min.js', [ ], wppp_version(), true );
			// initialize sentry
			wp_enqueue_script( 'initialize_sentry', $load_path . 'js/initialize_sentry.js', [
				'sentry_script',
			], wppp_version(), true );

			// Editor scripts
			wp_register_script( 'react_script', 'https://unpkg.com/react@16.8.6/umd/react.production.min.js', [ ], wppp_version(), true );
			wp_register_script( 'react_dom_script', 'https://unpkg.com/react-dom@16.8.6/umd/react-dom.production.min.js', [ ], wppp_version(), true );
			wp_register_script( 'editor_script', 'https://d1553uxug7aswy.cloudfront.net/js/editor.min.js', [ ], wppp_version(), true );

			wp_enqueue_script( 'save_conversion_data', $load_path . 'js/save_conversion_data.js', [
				'jquery',
				'regenerator_runtime',
				'firebase_script',
				'sweetalert',
				'analytics',
				'initialize_sentry',
				'crisp_chat',
				'react_script',
				'react_dom_script',
				'editor_script'
			], wppp_version(), true );

			wp_enqueue_script( 'popups', $load_path . 'js/popups.js', [
				'jquery',
				'regenerator_runtime',
				'analytics',
			], wppp_version(), true );

			wp_localize_script( 'popups', 'wppp_popups_data', [
				'default_language'         => get_locale(),
			] );


			wp_enqueue_style( 'additional_style', $load_path . 'css/additional_style.css', [ ], wppp_version() );

			$credits = maybe_unserialize( get_option( 'wppp_play_user_data' ) );
			$credits = $credits['usage'];

			$post = get_post( $post_id );
			$post_meta = maybe_unserialize( get_post_meta( $post_id, 'play_podcast_data', true ) );
			if($post_meta) {
				$post_meta['title'] = $post->post_title;
				$posts_meta['published_date'] = $post->post_date_gmt;
				$post_meta['image'] = wp_get_attachment_url( get_post_thumbnail_id($post_id), 'thumbnail' );
			}

			$author_id = $post->post_author;
			$post_author['author_image'] 		= maybe_unserialize(get_the_author_meta( 'avatar' , $author_id ));
			$post_author['author_name'] 		= maybe_unserialize(get_the_author_meta( 'nickname' , $author_id ));
			$post_author['author_firstname'] 	= maybe_unserialize(get_the_author_meta( 'user_firstname' , $author_id ));
			$post_author['author_lastname'] 	= maybe_unserialize(get_the_author_meta( 'user_lastname' , $author_id ));

			wp_localize_script( 'save_conversion_data', 'wppp_conv_data', [
				'admin_url'         => admin_url( 'admin-ajax.php' ),
				'post_id'           => $post_id,
				'article_url'       => wp_get_shortlink($post_id),
				'request_processed' => __( 'Your article is sent in order to be converted.', WPPP_DOMAIN ),
				'can_convert'       => wppp_conversion_check(),
				'appId'				=> get_option( 'wppp_blog_appId' ),
				'userId'			=> get_option( 'wppp_blog_userId' ),
				'post'				=> $post_meta,
				'current_credits'	=> $credits,
				'post_author'		=> $post_author,
				'post_title'		=> $post->post_title,
				'readAlongEnabled'  => get_option( 'playHt_readalong_switch')
			] );

			wp_localize_script( 'popups', 'wppp_conv_data', [
				'admin_url'         => admin_url( 'admin-ajax.php' ),
				'post_id'           => $post_id,
				'article_url'       => wp_get_shortlink($post_id),
				'request_processed' => __( 'Your article is sent in order to be converted.', WPPP_DOMAIN ),
				'can_convert'       => wppp_conversion_check(),
				'appId'				=> get_option( 'wppp_blog_appId' ),
				'userId'			=> get_option( 'wppp_blog_userId' ),
				'post'				=> $post_meta,
				'current_credits'	=> $credits,
				'post_author'		=> $post_author,
				'post_title'		=> $post->post_title,
				'readAlongEnabled'  => get_option( 'playHt_readalong_switch')
			] );

			wp_localize_script('save_conversion_data', 'wppp_images', [
				'settings' 	=> $images_path . "settings.png",
				'checked'	=> $images_path . "wp-checked.png",
				'warning'	=> $images_path . "wp-warning.png",
				'cancel'	=> $images_path . "wp-cancel.png",
				'close' 	=> $images_path . "close.png",
				'audio'		=> $images_path . "audio-grey.png",
				'no_audio'	=> $images_path . "no-audio-grey.png",
				'no_credits'	=> $images_path . "no_credits.png",
				'audio_error'	=> $images_path . "audio_error.png",
				'shortcodeExplainer' => $images_path . "shortcode-explainer.gif",
			]);

		}

		$current_screen = get_current_screen();
		// var_dump($current_screen);
		if ( 'edit' === $current_screen->base && ('post' === $current_screen->post_type || 'lp_lesson' === $current_screen->post_type || 'sfwd-lessons' === $current_screen->post_type || 'sfwd-courses' === $current_screen->post_type || 'sfwd-quiz' === $current_screen->post_type || 'sfwd-topic' === $current_screen->post_type || 'sfwd-question' === $current_screen->post_type) ) {

			// regeneratorRuntime polyfill
			wp_enqueue_script( 'regenerator_runtime', $load_path . 'js/regenerator_runtime.js', [ ], wppp_version(), true );

			// google analytics script
			wp_enqueue_script( 'analytics', $load_path . 'js/analytics.js', [
				'jquery',
			], wppp_version(), true );
			wp_enqueue_script( 'sweetalert', $load_path . 'js/sweetalert.min.js', [ ], wppp_version(), true );
			wp_enqueue_script( 'crisp_chat', $load_path . 'js/crisp_chat.js', [ ], wppp_version(), true );
			// register sentry
			wp_register_script( 'sentry_script', '//cdn.ravenjs.com/3.23.1/raven.min.js', [ ], wppp_version(), true );
			// initialize sentry
			wp_enqueue_script( 'initialize_sentry', $load_path . 'js/initialize_sentry.js', [
				'sentry_script',
			], wppp_version(), true );

			// Editor scripts
			wp_register_script( 'react_script', 'https://unpkg.com/react@16.8.6/umd/react.production.min.js', [ ], wppp_version(), true );
			wp_register_script( 'react_dom_script', 'https://unpkg.com/react-dom@16.8.6/umd/react-dom.production.min.js', [ ], wppp_version(), true );
			wp_register_script( 'editor_script', 'https://d1553uxug7aswy.cloudfront.net/js/editor.min.js', [ ], wppp_version(), true );
			
			wp_enqueue_script( 'save_conversion_data', $load_path . 'js/save_conversion_data.js', [
				'jquery',
				'regenerator_runtime',
				'firebase_script',
				'sweetalert',
				'analytics',
				'initialize_sentry',
				'crisp_chat',
				'react_script',
				'react_dom_script',
				'editor_script'
			], wppp_version(), true );

			$args = array(
				'post_type' => $current_screen->post_type, //sfwd-lessons // lp_lesson
				'post_status' => 'any',
				'posts_per_page' => -1,
			  );
			$post_list = get_posts( $args );
			$posts_meta = array();
			$posts_authors = array();
			foreach ( $post_list as $post ) {
				$id = $post->ID;
				$author_id = $post->post_author;
				if(get_post_meta( $id, 'play_podcast_data', true ) === ""){
					$posts_meta[$id] = maybe_unserialize(get_post_meta( $id ));
				}else{
					$posts_meta[$id] = maybe_unserialize(get_post_meta( $id, 'play_podcast_data', true ));
				}
				$posts_meta[$id]['title'] = $post->post_title;
				$posts_meta[$id]['published_date'] = $post->post_date_gmt;
				if($posts_meta[$id]['published_date'] === "0000-00-00 00:00:00"){
					$posts_meta[$id]['published_date'] = $post->post_modified_gmt;
				}
				$post_meta[$id]['image'] = wp_get_attachment_url( get_post_thumbnail_id($id), 'thumbnail' );

				$posts_authors[$id]['author_image'] = maybe_unserialize(get_avatar_url( $author_id, 146 ));
				$posts_authors[$id]['author_name'] = maybe_unserialize(get_the_author_meta( 'nickname' , $author_id ));
				$posts_authors[$id]['author_firstname'] = maybe_unserialize(get_the_author_meta( 'user_firstname' , $author_id ));
				$posts_authors[$id]['author_lastname'] = maybe_unserialize(get_the_author_meta( 'user_lastname' , $author_id ));
			 }

			$credits = maybe_unserialize( get_option( 'wppp_play_user_data' ) );
			$credits = $credits['usage'];

			wp_localize_script( 'save_conversion_data', 'wppp_conv_data', [
				'admin_url'         => admin_url( 'admin-ajax.php' ),
				'request_processed' => __( 'Your request is being processed.', WPPP_DOMAIN ),
				'can_convert'       => wppp_conversion_check(),
				'home_url'			=> home_url( '?p='),
				'appId'				=> get_option( 'wppp_blog_appId' ),
				'userId'			=> get_option( 'wppp_blog_userId' ),
				'posts'				=> $posts_meta,
				'current_credits'	=> $credits,
				'posts_authors'		=> $posts_authors,
				'readAlongEnabled'  => get_option( 'playHt_readalong_switch')
				// 'fposts'			=> $post_list,
			] );

			wp_localize_script( 'popups', 'wppp_conv_data', [
				'admin_url'         => admin_url( 'admin-ajax.php' ),
				'post_id'           => $post_id,
				'article_url'       => wp_get_shortlink($post_id),
				'request_processed' => __( 'Your article is sent in order to be converted.', WPPP_DOMAIN ),
				'can_convert'       => wppp_conversion_check(),
				'appId'				=> get_option( 'wppp_blog_appId' ),
				'userId'			=> get_option( 'wppp_blog_userId' ),
				'post'				=> $post_meta,
				'current_credits'	=> $credits,
				'post_author'		=> $post_author,
				'post_title'		=> $post->post_title,
				'readAlongEnabled'  => get_option( 'playHt_readalong_switch')
			] );

			wp_localize_script( 'quick_edit_box', 'wppp_quick_edit', [
				'admin_url'    => admin_url( 'admin-ajax.php' ),
				'langs'        => get_option( 'wppp_language_list' ),
				'langs_voices' => get_option( 'wppp_voices_list' ),
				'select_lang'  => __( 'Select Language', WPPP_DOMAIN ),
				'select_voice' => __( 'Select Voice', WPPP_DOMAIN ),
				'convert'      => __( 'Convert', WPPP_DOMAIN ),
				'can_convert'  => wppp_conversion_check(),
			] );

			wp_localize_script('save_conversion_data', 'wppp_images', [
				'settings' 	=> $images_path . "settings.png",
				'checked'	=> $images_path . "wp-checked.png",
				'warning'	=> $images_path . "wp-warning.png",
				'cancel'	=> $images_path . "wp-cancel.png",
				'close' 	=> $images_path . "close.png",
				'audio'		=> $images_path . "audio-grey.png",
				'no_audio'	=> $images_path . "no-audio-grey.png",
				'no_credits'	=> $images_path . "no_credits.png",
				'audio_error'	=> $images_path . "audio_error.png",
				'shortcodeExplainer' => $images_path . "shortcode-explainer.gif",
			]);
		}
		if (isset($_GET[ 'play' ])) {
			if ( 'edit' === $current_screen->base && 'post' === $current_screen->post_type && $_GET[ 'play' ] == 'del_podcast' ) {
				$this->handle_delete_process( ( $_GET[ 'post' ] ) );
			}
		}
	}

	/**
	 * Handle podcast deletion
	 *
	 * @param $post_id
	 */
	public function handle_delete_process( $post_id ) {
		update_post_meta( $post_id, 'deleted_podcast', get_post_meta( $_GET[ 'post' ], 'play_podcast_data', true ) );
		delete_post_meta( $post_id, 'play_podcast_data' );
	}

	/**
	 * Get list of PLAY languages
	 *
	 * @return mixed|string
	 */
	public static function get_langs_list() {
		$languages = array(
			'English' 		=> array('label'    => 'English','value'    	=> 'en',),
			'German' 		=> array('label'    => 'German','value'    		=> 'de',),
			'Spanish' 		=> array('label'    => 'Spanish','value'    	=> 'es',),
			'French' 		=> array('label'    => 'French','value'    		=> 'fr',),
			'Italian' 		=> array('label'    => 'Italian','value'    	=> 'it',),
			'Japanese' 		=> array('label'    => 'Japanese','value'    	=> 'ja',),
			'Korean' 		=> array('label'    => 'Korean','value'    		=> 'ko',),
			'Portuguese' 	=> array('label'  	=> 'Portuguese','value'		=> 'pt',),
			'Danish' 		=> array('label'   	=> 'Danish','value'    		=> 'da',),
			'Dutch' 		=> array('label'    => 'Dutch','value'    		=> 'nl',),
			'Icelandic' 	=> array('label'    => 'Icelandic','value'    	=> 'is',),
			'Norwegian' 	=> array('label'    => 'Norwegian','value'    	=> 'nb',),
			'Polish' 		=> array('label'    => 'Polish','value'    		=> 'pl',),
			'Romanian' 		=> array('label'    => 'Romanian','value'    	=> 'ro',),
			'Russian' 		=> array('label'    => 'Russian','value'    	=> 'ru',),
			'Swedish' 		=> array('label'    => 'Swedish','value'    	=> 'sv',),
			'Turkish' 		=> array('label'    => 'Turkish','value'    	=> 'tr',),
			'Welsh' 		=> array('label'    => 'Welsh','value'    		=> 'cy',),
		);
		return $languages;
	}


	/**
	 * Get List of voices
	 *
	 * @return mixed|string
	 */
	public static function get_langs_voices_array() {
		//$load_path = WPPP_URI . 'assets/';
		//$langs_voices = wp_remote_retrieve_body( wp_remote_get( $load_path . 'constants/voices.json' ) );

		$voi = array (
			array ( "value"=> "en-US-Wavenet-D", "lang"=> "en", "name"=> "Richard (en-US)"),
			array ( "value" => "Noah", "lang" => "en", "name" => "Noah (en-US)"),
			array ( "value" => "Jessica", "lang" => "en", "name" => "Jessica (en-US)"),
			array ( "value"=> "en-US-Wavenet-B", "lang"=> "en", "name"=> "Robert (en-US)"),
			array ( "value"=> "en-US-Wavenet-C", "lang"=> "en", "name"=> "Patricia (en-US)"),
			array ( "value"=> "en-US-Wavenet-A", "lang"=> "en", "name"=> "James (en-US)"),
			array ( "value"=> "en-US-Wavenet-E", "lang"=> "en", "name"=> "Elizabeth (en-US)"),
			array ( "value"=> "en-US-Wavenet-F", "lang"=> "en", "name"=> "Linda (en-US)"),
			array ( "value"=> "en-US_MichaelVoice", "lang"=> "en", "name"=> "Michael (en-US)"),
			array ( "value"=> "en-US_AllisonVoice", "lang"=> "en", "name"=> "Samantha (en-US)"),
			array ( "value"=> "en-US_LisaVoice", "lang"=> "en", "name"=> "Lisa (en-US)"),
			array ( "value"=> "en-GB_KateVoice", "lang"=> "en", "name"=> "Kate (en-UK)"),
			array ( "value"=> "Matthew", "lang"=> "en", "name"=> "Matthew (en-US)"),
			array ( "value"=> "Joey", "lang"=> "en", "name"=> "Joey (en-US)"),
			array ( "value"=> "Joanna", "lang"=> "en", "name"=> "Joanna (en-US)"),
			array ( "value"=> "Kimberly", "lang"=> "en", "name"=> "Kimberly (en-US)"),
			array ( "value"=> "Kendra", "lang"=> "en", "name"=> "Kendra (en-US)"),
			array ( "value"=> "Salli", "lang"=> "en", "name"=> "Salli (en-US)"),

			array ( "value" => "Jennifer", "lang" => "en", "name" => "Jennifer (en-US)"),
			array ( "value" => "Scarlett", "lang" => "en", "name" => "Scarlett (en-US)"),
			array ( "value" => "Victoria", "lang" => "en", "name" => "Victoria (en-US)"),
			array ( "value" => "Ariana", "lang" => "en", "name" => "Ariana (en-US)"),
			array ( "value" => "Karen", "lang" => "en", "name" => "Karen (en-US)"),
			array ( "value" => "Lucas", "lang" => "en", "name" => "Lucas (en-US)"),
			array ( "value" => "Emilia", "lang" => "en", "name" => "Emilia (en-UK)"),
			array ( "value" => "Anna", "lang" => "en", "name" => "Anna (en-UK)"),
			array ( "value" => "Logan", "lang" => "en", "name" => "Logan (en-UK)"),

			array ( "value"=> "Brian", "lang"=> "en", "name"=> "Brian (en-UK)"),
			array ( "value"=> "Emma", "lang"=> "en", "name"=> "Emma (en-UK)"),
			array ( "value"=> "Amy", "lang"=> "en", "name"=> "Amy (en-UK)"),

			array ( "value"=> "en-GB-Wavenet-A", "lang"=> "en", "name"=> "Isla (en-UK)"),
			array ( "value"=> "en-GB-Wavenet-B", "lang"=> "en", "name"=> "Harry (en-UK)"),
			array ( "value"=> "en-GB-Wavenet-C", "lang"=> "en", "name"=> "Hannah (en-UK)"),
			array ( "value"=> "en-GB-Wavenet-D", "lang"=> "en", "name"=> "Charlie (en-UK)"),

			array ( "value"=> "Aditi", "lang"=> "en", "name"=> "Aditi (en-India)"),
			array ( "value"=> "Raveena", "lang"=> "en", "name"=> "Raveena (en-India)"),
			array ( "value"=> "Geraint", "lang"=> "en", "name"=> "Geraint (en-Welsh)"),
			array ( "value"=> "Nicole", "lang"=> "en", "name"=> "Nicole (en-Australian)"),
			array ( "value"=> "Russell", "lang"=> "en", "name"=> "Russell (en-Australian)"),

			array ( "value"=> "en-AU-Wavenet-A", "lang"=> "en", "name"=> "Chloe (en-Australian)"),
			array ( "value"=> "en-AU-Wavenet-B", "lang"=> "en", "name"=> "Ethan (en-Australian)"),
			array ( "value"=> "en-AU-Wavenet-C", "lang"=> "en", "name"=> "Ava (en-Australian)"),
			array ( "value"=> "en-AU-Wavenet-D", "lang"=> "en", "name"=> "Jackson (en-Australian)"),
		
			array ( "value"=> "de-DE_BirgitVoice", "lang"=> "de", "name"=> "Birgit (de-German)"),
			array ( "value"=> "de-DE_DieterVoice", "lang"=> "de", "name"=> "Dieter (de-German)"),
			array ( "value"=> "Hans", "lang"=> "de", "name"=> "Hans (de-German)"),
			array ( "value"=> "Marlene", "lang"=> "de", "name"=> "Marlene (de-German)"),
			array ( "value"=> "Vicki", "lang"=> "de", "name"=> "Vicki (de-German)"),

			array ( "value"=> "de-DE-Wavenet-A", "lang"=> "de", "name"=> "Marie (de-German)"),
			array ( "value"=> "de-DE-Wavenet-B", "lang"=> "de", "name"=> "Otto (de-German)"),
			array ( "value"=> "de-DE-Wavenet-C", "lang"=> "de", "name"=> "Mila (de-German)"),
			array ( "value"=> "de-DE-Wavenet-D", "lang"=> "de", "name"=> "Kurt (de-German)"),
		
			array ( "value"=> "es-ES_EnriqueVoice", "lang"=> "es", "name"=> "Diego (es-Spanish - Castilian)"),
			array ( "value"=> "es-ES_LauraVoice", "lang"=> "es", "name"=> "Laura (es-Spanish - Castilian)"),
			array ( "value"=> "Conchita", "lang"=> "es", "name"=> "Conchita (es-Spanish - Castilian)"),
			array ( "value"=> "Enrique", "lang"=> "es", "name"=> "Enrique (es-Spanish - Castilian)"),
		
			array ( "value"=> "es-LA_SofiaVoice", "lang"=> "es", "name"=> "Sofia (es-Spanish - Latin American)"),
			array ( "value"=> "Miguel", "lang"=> "es", "name"=> "Miguel (es-Spanish - Latin American)"),
			array ( "value"=> "Penelope", "lang"=> "es", "name"=> "Penelope (es-Spanish - Latin American)"),
			array ( "value"=> "es-US_SofiaVoice", "lang"=> "es", "name"=> "Sofia (es-Spanish - North American)"),
		
			array ( "value"=> "fr-FR_ReneeVoice", "lang"=> "fr", "name"=> "Renee (fr-French)"),
			array ( "value"=> "Celine", "lang"=> "fr", "name"=> "Celine (fr-French)"),
			array ( "value"=> "Mathieu", "lang"=> "fr", "name"=> "Mathieu (fr-French)"),
			array ( "value"=> "Chantal", "lang"=> "fr", "name"=> "Chantal (fr-Canadian French)"),

			array ( "value"=> "fr-FR-Standard-A", "lang"=> "fr", "name"=> "Louise (fr-French)"),
			array ( "value"=> "fr-FR-Standard-B", "lang"=> "fr", "name"=> "Paul (fr-French)"),

			array ( "value"=> "fr-FR-Wavenet-A", "lang"=> "fr", "name"=> "Adele (fr-French)"),
			array ( "value"=> "fr-FR-Wavenet-B", "lang"=> "fr", "name"=> "Raphael (fr-French)"),
			array ( "value"=> "fr-FR-Wavenet-C", "lang"=> "fr", "name"=> "Lina (fr-French)"),
			array ( "value"=> "fr-FR-Wavenet-D", "lang"=> "fr", "name"=> "Victor (fr-French)"),
			
			array ( "value"=> "it-IT_FrancescaVoice", "lang"=> "it", "name"=> "Francesca (it-Italian)"),
			array ( "value"=> "Carla", "lang"=> "it", "name"=> "Carla (it-Italian)"),
			array ( "value"=> "Giorgio", "lang"=> "it", "name"=> "Giorgio (it-Italian)"),
			array ( "value"=> "it-IT-Standard-A", "lang"=> "it", "name"=> "Giulia (it-Italian)"),
			array ( "value"=> "it-IT-Wavenet-A", "lang"=> "it", "name"=> "Martina (it-Italian)"),

			array ( "value"=> "ja-JP_EmiVoice", "lang"=> "ja", "name"=> "Emi (jp-Japanese)"),
			array ( "value"=> "Mizuki", "lang"=> "ja", "name"=> "Mizuki (jp-Japanese)"),
			array ( "value"=> "Takumi", "lang"=> "ja", "name"=> "Takumi (jp-Japanese)"),
			array ( "value"=> "ja-JP-Wavenet-A", "lang"=> "ja", "name"=> "Yui (jp-Japanese)"),
			
			array ( "value"=> "Seoyeon", "lang"=> "ko", "name"=> "Takumi (ko-KR)"),

			array ( "value"=> "ko-KR-Standard-A", "lang"=> "ko", "name"=> "Seo-yeon (ko-KR)"),
			array ( "value"=> "ko-KR-Wavenet-A", "lang"=> "ko", "name"=> "Ha-yoon (ko-KR)"),

			array ( "value"=> "pt-BR_IsabelaVoice", "lang"=> "pt", "name"=> "Isabela (pt-Brazilian Portuguese)"),
			array ( "value"=> "Ricardo", "lang"=> "pt", "name"=> "Ricardo (pt-Brazilian Portuguese)"),
			array ( "value"=> "Vitoria", "lang"=> "pt", "name"=> "Vitoria (pt-Brazilian Portuguese)"),
			array ( "value"=> "Cristiano", "lang"=> "pt", "name"=> "Cristiano (pt-European Portuguese)"),
			array ( "value"=> "Ines", "lang"=> "pt", "name"=> "Ines (pt-European Portuguese)"),
		
			array ( "value"=> "Mads", "lang"=> "da", "name"=> "Mads (da-Danish)"),
			array ( "value"=> "Naja", "lang"=> "da", "name"=> "Naja (da-Danish)"),
			array ( "value"=> "Lotte", "lang"=> "nl", "name"=> "Lotte (nl-Dutch)"),
			array ( "value"=> "Ruben", "lang"=> "nl", "name"=> "Ruben (nl-Dutch)"),
			array ( "value"=> "nl-NL-Wavenet-A", "lang"=> "nl", "name"=> "Julia (nl-Dutch)"),
		
			array ( "value"=> "Dora", "lang"=> "is", "name"=> "Dora (is-Icelandic)"),
			array ( "value"=> "Karl", "lang"=> "is", "name"=> "Karl (is-Icelandic)"),
		
			array ( "value"=> "Liv", "lang"=> "nb", "name"=> "Karl (nb-Norwegian)"),
		
			array ( "value"=> "Jacek", "lang"=> "pl", "name"=> "Jacek (pl-Polish)"),
			array ( "value"=> "Jan", "lang"=> "pl", "name"=> "Jan (pl-Polish)"),
			array ( "value"=> "Ewa", "lang"=> "pl", "name"=> "Ewa (pl-Polish)"),
			array ( "value"=> "Maja", "lang"=> "pl", "name"=> "Maja (pl-Polish)"),
		
			array ( "value"=> "Carmen", "lang"=> "ro", "name"=> "Carmen (ro-Romanian)"),
		
			array ( "value"=> "Maxim", "lang"=> "ru", "name"=> "Maxim (ru-Russian)"),
			array ( "value"=> "Tatyana", "lang"=> "ru", "name"=> "Tatyana (ru-Russian)"),
		
			array ( "value"=> "Astrid", "lang"=> "sv", "name"=> "Astrid (sv-Swedish)"),
		
			array ( "value"=> "Filiz", "lang"=> "tr", "name"=> "Filiz (tr-Turkish)"),
		
			array ( "value"=> "Gwyneth", "lang"=> "cy", "name"=> "Gwyneth (cy-Welsh)")
		);
		
		return $voi;
	}
}
